# Bug Reporting

There will be bugs and I'll work on fixing them.

But please if you run into anything that seems off don't
hesitate to create an issue on the repo.

Please be detailed as possible in your issue when describing the bug
including providing a minimal reproducible example.

i.e. if your command didn't work provide the exact command you used.
